You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@systemds.apache.org by GitBox <gi...@apache.org> on 2022/12/21 10:45:01 UTC

[GitHub] [systemds] Baunsgaard commented on pull request #1750: [SYSTEMDS-3478] Bitset array for Frames

Baunsgaard commented on PR #1750:
URL: https://github.com/apache/systemds/pull/1750#issuecomment-1361154199

   This pr improve performance and allocation of frames  in memory and on disk reduced size of 8x of boolean values.
    
   on a 64kx2k frame with booleans:
   
   - write time improved from 0.3-0.6 to 0.162
   - read time improved from 0.4 to 0.119
   - size on disk and memory from 128MB to 16MB
   
   This commit is done to provide a lower bound case for dense boolean allocation.
   


-- 
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

To unsubscribe, e-mail: dev-unsubscribe@systemds.apache.org

For queries about this service, please contact Infrastructure at:
users@infra.apache.org